@@ -1,6 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2003, 2007-2012, 2014-2018 Free Software Foundation,
-   Inc.
+   Copyright (C) 2003-2023 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -17,7 +16,9 @@
 
 #include "imap4d.h"
 
-struct mu_tls_config global_tls_conf;
+static int global_conf_status = -1;
+int global_tls_mode;
+struct mu_tls_config global_tls_conf = { .handshake_timeout = 10 };
 
 /*
 6.2.1.  STARTTLS Command
@@ -68,6 +69,70 @@ tls_encryption_on (struct imap4d_session *session)
   imap4d_capability_remove (IMAP_CAPA_XTLSREQUIRED);
 }
 
+int
+starttls_server_check (struct imap4d_srv_config *cfg, char const *srvid)
+{
+  int result;
+  
+  switch (cfg->tls_mode)
+    {
+    case tls_unspecified:
+      if (global_tls_mode != tls_unspecified)
+	cfg->tls_mode = global_tls_mode;
+      else if (cfg->tls_conf.cert_file)
+	cfg->tls_mode = tls_ondemand;
+      else
+	{
+	  cfg->tls_mode = tls_no;
+	  return MU_TLS_CONFIG_NULL;
+	}
+      break;
+
+    case tls_no:
+      return MU_TLS_CONFIG_NULL;
+
+    default:
+      break;
+    }
+
+  result = mu_tls_config_check (&cfg->tls_conf, 1);
+  switch (result)
+    {
+    case MU_TLS_CONFIG_OK:
+      if (!cfg->tls_conf.cert_file)
+	{
+	  mu_error (_("server %s: no certificate set"), srvid);
+	  result = MU_TLS_CONFIG_FAIL;
+	}
+      break;
+
+    case MU_TLS_CONFIG_NULL:
+      if (global_conf_status == -1)
+	{
+	  if (global_tls_conf.cert_file)
+	    global_conf_status = mu_tls_config_check (&global_tls_conf, 1);
+	  else
+	    global_conf_status = MU_TLS_CONFIG_NULL;
+	}
+
+      if (global_conf_status != MU_TLS_CONFIG_NULL)
+	{
+	  cfg->tls_conf = global_tls_conf;
+	  result = MU_TLS_CONFIG_OK;
+	}
+      else
+	{
+	  mu_error (_("server %s: no certificate set"), srvid);
+	  result = MU_TLS_CONFIG_FAIL;
+	}
+      break;
+
+    default:
+      mu_error (_("server %s: TLS configuration failed"), srvid);
+    }
+  return result;
+}
+
 int
 starttls_init (mu_m_server_t msrv)
 {
@@ -76,12 +141,6 @@ starttls_init (mu_m_server_t msrv)
   int errors = 0;
   int tls_ok = mu_init_tls_libs ();
   int tls_requested = 0;
-  int global_conf_status = 0;
-
-  if (global_tls_conf.cert_file)
-    global_conf_status = mu_tls_config_check (&global_tls_conf, 1);
-  else
-    global_conf_status = MU_TLS_CONFIG_NULL;
   
   mu_m_server_get_srvlist (msrv, &srvlist);
   mu_list_get_iterator (srvlist, &itr);
@@ -91,51 +150,15 @@ starttls_init (mu_m_server_t msrv)
       struct imap4d_srv_config *cfg;
       mu_iterator_current (itr, (void**) &ipsrv);
       cfg = mu_ip_server_get_data (ipsrv);
-      switch (cfg->tls_mode)
+      switch (starttls_server_check (cfg, mu_ip_server_addrstr (ipsrv)))
 	{
-	case tls_unspecified:
-	  if (cfg->tls_conf.cert_file)
-	    {
-	      cfg->tls_mode = tls_ondemand;
-	      break;
-	    }
-	  else
-	    cfg->tls_mode = tls_no;
-	  /* fall through */
-	case tls_no:
+	case MU_TLS_CONFIG_NULL:
 	  continue;
 	  
-	default:
-	  break;
-	}
-
-      switch (mu_tls_config_check (&cfg->tls_conf, 1))
-	{
 	case MU_TLS_CONFIG_OK:
-	  if (!cfg->tls_conf.cert_file)
-	    {
-	      mu_error (_("server %s: no certificate set"),
-			mu_ip_server_addrstr (ipsrv));
-	      errors = 1;
-	    }
-	  break;
-	  
-	case MU_TLS_CONFIG_NULL:
-	  if (global_conf_status != MU_TLS_CONFIG_NULL)
-	    {
-	      cfg->tls_conf = global_tls_conf;
-	    }
-	  else
-	    {
-	      mu_error (_("server %s: no certificate set"),
-			mu_ip_server_addrstr (ipsrv));
-	      errors = 1;
-	    }
 	  break;
 
 	default:
-	  mu_error (_("server %s: TLS configuration failed"),
-		    mu_ip_server_addrstr (ipsrv));
 	  errors = 1;
 	}
       
@@ -143,6 +166,9 @@ starttls_init (mu_m_server_t msrv)
     }
   mu_iterator_destroy (&itr);
 
+  if (global_tls_mode == tls_unspecified)
+    global_tls_mode = tls_no;
+
   if (tls_requested && !tls_ok)
     {
       mu_error (_("TLS is not configured, but requested in the "
