@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2020 Free Software Foundation, Inc.
+   Copyright (C) 1999-2023 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -56,6 +56,7 @@ extern int  mu_mailbox_flush           (mu_mailbox_t mbox, int expunge);
 extern int  mu_mailbox_get_folder      (mu_mailbox_t, mu_folder_t *);
 extern int  mu_mailbox_set_folder      (mu_mailbox_t, mu_folder_t);
 extern int  mu_mailbox_uidvalidity     (mu_mailbox_t, unsigned long *);
+extern int  mu_mailbox_uidvalidity_reset (mu_mailbox_t);
 extern int  mu_mailbox_uidnext         (mu_mailbox_t, size_t *);
 extern int  mu_mailbox_access_time (mu_mailbox_t mbox, time_t *return_time);
 
@@ -65,6 +66,10 @@ extern int  mu_mailbox_get_message     (mu_mailbox_t, size_t msgno,
 extern int  mu_mailbox_quick_get_message(mu_mailbox_t, mu_message_qid_t,
 					 mu_message_t *); 
 extern int  mu_mailbox_append_message  (mu_mailbox_t, mu_message_t);
+extern int  mu_mailbox_append_message_ext (mu_mailbox_t mbox, mu_message_t msg,
+					   mu_envelope_t env,
+					   mu_attribute_t atr);
+  
 extern int  mu_mailbox_messages_count  (mu_mailbox_t, size_t *);
 extern int  mu_mailbox_messages_recent (mu_mailbox_t, size_t *);
 extern int  mu_mailbox_message_unseen  (mu_mailbox_t, size_t *);
