@@ -1,6 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2000, 2004-2012, 2014-2017 Free Software
-   Foundation, Inc.
+   Copyright (C) 1999-2023 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -64,7 +63,6 @@ void mu_registrar_set_default_record (mu_record_t record);
   
 /* Registration.  */
 int mu_registrar_get_iterator (mu_iterator_t *);
-int mu_registrar_get_list (mu_list_t *) MU_DEPRECATED;
 
 int mu_registrar_lookup_scheme (const char *scheme,
 				       mu_record_t *precord);
@@ -75,8 +73,17 @@ int mu_registrar_lookup_url (mu_url_t url, int flags,
 				    mu_record_t *precord, int *pflags);
 int mu_registrar_record       (mu_record_t);
 int mu_unregistrar_record     (mu_record_t);
+
 int mu_registrar_apply_filter (int (*flt) (mu_record_t, void *), void *data);
 
+struct mu_record_match
+{
+  mu_record_t record;
+  int flags;
+};
+
+int mu_registrar_match_records (char const *name, int flags, mu_list_t *ret);
+
 int mu_record_is_local (mu_record_t);
   
 /* Scheme.  */
@@ -94,6 +101,7 @@ int mu_record_get_mailer      (mu_record_t, int (*(*)) (mu_mailer_t));
 int mu_record_get_folder      (mu_record_t, int (*(*)) (mu_folder_t));
   
 int mu_record_list_p (mu_record_t record, const char *name, int);
+int mu_registrar_list_p (mu_list_t rlist, char const *name, int flags);
   
 /* Records provided by the library.  */
 
@@ -103,11 +111,10 @@ extern mu_record_t mu_imaps_record;
 /* Remote Mailbox POP3, pop://  */
 extern mu_record_t mu_pop_record;
 extern mu_record_t mu_pops_record;
-/* Remote newsgroup NNTP, nntp://  */
-extern mu_record_t mu_nntp_record;
 
 /* Local Mailbox Unix Mailbox, "mbox:"  */
 extern mu_record_t mu_mbox_record;
+
 /* Local MH, "mh:" */
 extern mu_record_t mu_mh_record;
 /* Maildir, "maildir:" */
@@ -118,7 +125,6 @@ extern mu_record_t mu_maildir_record;
 #define MU_MBOX_PRIO        300 
 #define MU_MAILDIR_PRIO     400 
 #define MU_MH_PRIO          500
-#define MU_NNTP_PRIO        600
 #define MU_PATH_PRIO        1000
   
 #define MU_SMTP_PRIO        10000
@@ -132,9 +138,12 @@ extern mu_record_t mu_smtps_record;
 extern mu_record_t mu_sendmail_record;
 /* Program mailer, "prog://", "|" */
 extern mu_record_t mu_prog_record;
+
+extern mu_record_t mu_dotmail_record;
   
 #define mu_register_all_mbox_formats() do {\
   mu_registrar_record (mu_mbox_record);\
+  mu_registrar_record (mu_dotmail_record);\
   mu_registrar_record (mu_pop_record);\
   mu_registrar_record (mu_pops_record);\
   mu_registrar_record (mu_imap_record);\
@@ -146,6 +155,7 @@ extern mu_record_t mu_prog_record;
 
 #define mu_register_local_mbox_formats() do {\
   mu_registrar_record (mu_mbox_record);\
+  mu_registrar_record (mu_dotmail_record);\
   mu_registrar_record (mu_mh_record);\
   mu_registrar_record (mu_maildir_record);\
   mu_registrar_set_default_record (MU_DEFAULT_RECORD);\
@@ -156,7 +166,6 @@ extern mu_record_t mu_prog_record;
   mu_registrar_record (mu_pops_record);\
   mu_registrar_record (mu_imap_record);\
   mu_registrar_record (mu_imaps_record);\
-  mu_registrar_record (mu_nntp_record);\
 } while (0)
 
 #define mu_register_all_mailer_formats() do {\
@@ -166,9 +175,7 @@ extern mu_record_t mu_prog_record;
   mu_registrar_record (mu_prog_record);\
 } while (0)
 
-#define mu_register_extra_formats() do {\
-  mu_registrar_record (mu_nntp_record);\
-} while (0)
+#define mu_register_extra_formats()
 
 #define mu_register_all_formats() do {\
   mu_register_all_mbox_formats ();\
