@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2005-2022 Free Software Foundation, Inc.
+   Copyright (C) 2005-2023 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -134,8 +134,12 @@ mime_context_get_temp_file (struct mime_context *ctx, char **ptr)
   if (!ctx->temp_file)
     {
       int fd;
-      if (mu_tempfile (NULL, 0, &fd, &ctx->temp_file))
-	return -1;
+      int rc;
+      if ((rc = mu_tempfile (NULL, 0, &fd, &ctx->temp_file)) != 0)
+	{
+	  mu_diag_funcall (MU_DIAG_ERROR, "mu_tempfile", NULL, rc);
+	  return -1;
+	}
       mime_context_write_input (ctx, fd);
       close (fd);
       ctx->unlink_temp_file = 1;
@@ -162,7 +166,8 @@ expand_string (struct mime_context *ct, char const *input, char **pstr)
 	    switch (p[1])
 	      {
 	      case 's':
-		mime_context_get_temp_file (ct, &s);
+		if (mime_context_get_temp_file (ct, &s))
+		  return -1;
 		mu_opool_appendz (expand_pool, s);
 		rc = 1;
 		p += 2;
@@ -323,8 +328,11 @@ create_filter (char *cmd, int outfd, int *infd)
   pid_t pid;
   int lp[2];
 
-  if (infd)
-    pipe (lp);
+  if (infd && pipe (lp))
+    {
+      mu_error ("pipe: %s", mu_strerror (errno));
+      return -1;
+    }
 
   pid = fork ();
   if (pid == -1)
@@ -427,10 +435,14 @@ run_test (mu_mailcap_entry_t entry, struct mime_context *ctx)
     {
       char *str;
       char *argv[] = { "/bin/sh", "-c", NULL, NULL };
-      expand_string (ctx, value, &str);
-      argv[2] = str;
-      if (mu_spawnvp (argv[0], argv, &status))
+      if (expand_string (ctx, value, &str))
 	status = 1;
+      else
+	{
+	  argv[2] = str;
+	  if (mu_spawnvp (argv[0], argv, &status))
+	    status = 1;
+	}
     }
   return status;
 }
@@ -466,12 +478,19 @@ run_mailcap (mu_mailcap_entry_t entry, struct mime_context *ctx)
   if (status)
     return 1;
 
-  /* NOTE: We don't create temporary file for %s, we just use
-     mimeview_file instead */
-  if (expand_string (ctx, view_command, &command))
-    pfd = NULL;
-  else
-    pfd = &fd;
+  switch (expand_string (ctx, view_command, &command))
+    {
+    case 0:
+      pfd = &fd;
+      break;
+
+    case 1:
+      pfd = NULL;
+      break;
+
+    default:
+      return 1;
+    }
   mu_debug (ctx->dh, MU_DEBUG_TRACE0, (_("executing %s...\n"), command));
 
   if (!confirm_action (ctx, command))
@@ -481,7 +500,10 @@ run_mailcap (mu_mailcap_entry_t entry, struct mime_context *ctx)
 
   if (interactive_p (ctx)
       && mu_mailcap_entry_sget_field (entry, MU_MAILCAP_COPIOUSOUTPUT, NULL) == 0)
-    create_filter (get_pager (), -1, &outfd);
+    {
+      if (create_filter (get_pager (), -1, &outfd) < 0)
+	return -1;
+    }
 
   pid = create_filter (command, outfd, pfd);
   if (pid > 0)
