@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2020 Free Software Foundation, Inc.
+   Copyright (C) 1999-2023 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -15,6 +15,7 @@
    along with GNU Mailutils.  If not, see <http://www.gnu.org/licenses/>. */
 
 #include <config.h>
+#include <stdlib.h>
 #include <mailutils/types.h>
 #include <mailutils/alloc.h>
 #include <mailutils/cstr.h>
@@ -32,3 +33,15 @@ unistr_is_substring (char const *haystack, char const *needle)
 {
   return mu_c_strcasestr (haystack, needle) != NULL;
 }
+
+int
+unistr_is_substring_dn (char const *haystack, char const *needle)
+{
+  char *lc;
+  int result;
+  
+  unistr_downcase (haystack, &lc);
+  result = mu_c_strcasestr (lc, needle) != NULL;
+  free (lc);
+  return result;
+}
