@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2020 Free Software Foundation, Inc.
+   Copyright (C) 1999-2023 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
@@ -34,10 +34,6 @@ mu_record_t mu_pop_record = NULL;
 mu_record_t mu_pops_record = NULL;
 #endif
 
-#ifndef ENABLE_NNTP
-mu_record_t mu_nntp_record = NULL;
-#endif
-
 #ifndef ENABLE_MH
 mu_record_t mu_mh_record = NULL;
 #endif
