@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2014-2021 Free Software Foundation, Inc.
+   Copyright (C) 2014-2023 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
@@ -74,7 +74,7 @@ ch2ent (int c)
 
 struct xml_encode_state
 {
-  char buf[11]; /* Enough to acomodate &#x10FFFF; - max. UTF-8 codepoint */
+  char buf[11]; /* Enough to accommodate &#x10FFFF; - max. UTF-8 codepoint */
   int idx;
 };
 
