@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2019 Free Software Foundation, Inc.
+   Copyright (C) 1999-2023 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -1214,8 +1214,8 @@ header_size (mu_stream_t str, mu_off_t *psize)
   return status;
 }
 
-static int
-_header_get_stream (mu_header_t header, mu_stream_t *pstream, int ref)
+int
+mu_header_get_streamref (mu_header_t header, mu_stream_t *pstream)
 {
   if (header == NULL)
     return EINVAL;
@@ -1238,27 +1238,9 @@ _header_get_stream (mu_header_t header, mu_stream_t *pstream, int ref)
       str->hdr = header;
       header->stream = (mu_stream_t) str;
     }
-  if (!ref)
-    {
-      *pstream = header->stream;
-      return 0;
-    }
   return mu_streamref_create (pstream, header->stream);
 }
 
-int
-mu_header_get_stream (mu_header_t header, mu_stream_t *pstream)
-{
-  /* FIXME: Deprecation warning */
-  return _header_get_stream (header, pstream, 0);
-}
-
-int
-mu_header_get_streamref (mu_header_t header, mu_stream_t *pstream)
-{
-  return _header_get_stream (header, pstream, 1);
-}
-
 
 int
 mu_header_set_fill (mu_header_t header, int
