@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2009-2022 Free Software Foundation, Inc.
+   Copyright (C) 2009-2023 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
@@ -529,6 +529,15 @@ filter_ctl (struct _mu_stream *stream, int code, int opcode, void *ptr)
 	      break;
 
 	    case MU_IOCTL_OP_SET:
+	      if (pstr[1] != NULL)
+		{
+		  mu_stream_t iostr;
+		  status = mu_iostream_create (&iostr, pstr[0], pstr[1]);
+		  if (status)
+		    return status;
+		  pstr[0] = iostr;
+		}
+		  
 	      mu_stream_unref (fs->transport);
 	      fs->transport = pstr[0];
 	      mu_stream_ref (fs->transport);
