@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2016-2021 Free Software Foundation, Inc.
+   Copyright (C) 2016-2023 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
@@ -33,6 +33,7 @@ struct mu_wordwrap_stream
   unsigned right_margin;
   char *buffer;
   unsigned offset;
+  int overflow;
   mu_stream_t transport;
 };
 
@@ -42,6 +43,12 @@ is_word (int c)
   return !mu_isspace (c);
 }
 
+static int
+line_not_empty (struct mu_wordwrap_stream *str)
+{
+  return (str->overflow && str->offset > 0) || str->offset > str->left_margin;
+}
+
 static int
 full_write (struct mu_wordwrap_stream *str, size_t length)
 {
@@ -65,23 +72,27 @@ _wordwrap_flush_line (struct mu_wordwrap_stream *str, int lookahead)
   int nl = 0;
   char savech;
   int rc;
-  
+
   length = word_start = str->offset;
   if (str->offset > 0 && lookahead)
     {
       if (is_word (str->buffer[str->offset - 1]) && is_word (lookahead))
 	{
+	  unsigned start = str->overflow ? 0 : str->left_margin;
 	  /* Find the nearest word boundary */
-	  for (length = str->offset; length > str->left_margin; length--)
+	  for (length = str->offset; length > start; length--)
 	    {
 	      if (!is_word (str->buffer[length - 1]))
 		break;
 	    }
-	  if (length == str->left_margin)
+	  if (length == start)
 	    {
 	      rc = full_write (str, str->offset);
 	      if (rc == 0)
-		str->offset = 0;
+		{
+		  str->offset = 0;
+		  str->overflow = 1;
+		}
 	      return rc;
 	    }
 	  word_start = length;
@@ -90,7 +101,7 @@ _wordwrap_flush_line (struct mu_wordwrap_stream *str, int lookahead)
 
   while (length > 0 && mu_isspace (str->buffer[length - 1]))
     length--;
-  
+
   if (length == 0 || str->buffer[length - 1] != '\n')
     {
       savech = str->buffer[length];
@@ -102,12 +113,11 @@ _wordwrap_flush_line (struct mu_wordwrap_stream *str, int lookahead)
   
   /* Flush the line buffer content */
   rc = full_write (str, length + nl);
+  if (nl)
+    str->buffer[length] = savech;
   if (rc)
     /* FIXME: Inconsistent state after error */
     return rc;
-
-  if (nl)
-    str->buffer[length] = savech;
   
   /* Adjust the buffer */
   memset (str->buffer, ' ', str->left_margin);
@@ -119,6 +129,7 @@ _wordwrap_flush_line (struct mu_wordwrap_stream *str, int lookahead)
 		 word_len);
     }
   str->offset = str->left_margin + word_len;
+  str->overflow = 0;
   return 0;
 }
   
@@ -132,13 +143,17 @@ _wordwrap_write (mu_stream_t stream, const char *iptr, size_t isize,
   for (n = 0; n < isize; n++)
     {
       if (str->offset == str->right_margin
-	  || (str->offset > str->left_margin
-	      && str->buffer[str->offset - 1] == '\n'))
+	  || (line_not_empty (str) && str->buffer[str->offset - 1] == '\n'))
 	_wordwrap_flush_line (str, iptr[n]);
-      if (str->offset == str->left_margin && mu_isblank (iptr[n]))
+      if (!str->overflow && str->offset == str->left_margin && mu_isblank (iptr[n]))
 	continue;
       str->buffer[str->offset++] = iptr[n];
     }
+  if (str->overflow)
+    {
+      full_write (str, str->offset);
+      str->offset = 0;
+    }
   if (nbytes)
     *nbytes = isize;
   return 0;
@@ -148,7 +163,7 @@ static int
 _wordwrap_flush (mu_stream_t stream)
 {
   struct mu_wordwrap_stream *str = (struct mu_wordwrap_stream *)stream;
-  if (str->offset > str->left_margin)
+  if (line_not_empty (str))
     _wordwrap_flush_line (str, 0);
   return mu_stream_flush (str->transport);
 }
@@ -183,7 +198,7 @@ set_margin (mu_stream_t stream, unsigned lmargin, int off)
      column, or it equals the current column and the character in previous
      column is a word constituent, or the last character on line is a newline.
   */
-  if (str->offset > str->left_margin
+  if (line_not_empty (str)
       && (lmargin < str->offset
 	  || (lmargin == str->offset && is_word (str->buffer[str->offset - 1]))
 	  || str->buffer[str->offset - 1] == '\n'))
@@ -193,7 +208,8 @@ set_margin (mu_stream_t stream, unsigned lmargin, int off)
     memset (str->buffer + str->offset, ' ', lmargin - str->offset);
   str->left_margin = lmargin;
   str->offset = lmargin;
-
+  str->overflow = 0;
+  
   return 0;
 }
 
