@@ -1,6 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2002, 2006-2008, 2010-2012, 2014-2016 Free Software
-   Foundation, Inc.
+   Copyright (C) 2002-2023 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -119,32 +118,21 @@ getpwnam_ip_virtual (const char *u)
     {
       char *ip;
       char *user;
+      struct addrinfo *res;
+      char hostbuf[NI_MAXHOST];
 
-      struct hostent *info = gethostbyaddr ((char *)&addr.sin_addr,
-					    4, AF_INET);
-
-      if (info)
+      if (getnameinfo((struct sockaddr *)&addr, len,
+		      hostbuf, sizeof(hostbuf),
+		      NULL, 0, 0) == 0)
 	{
-	  user = malloc (strlen (info->h_name) + strlen (u) + 2);
+	  user = malloc (strlen (hostbuf) + strlen (u) + 2);
 	  if (user)
 	    {
-	      sprintf (user, "%s!%s", u, info->h_name);
+	      sprintf (user, "%s!%s", u, hostbuf);
 	      pw = getpwnam_virtual (user);
 	      free (user);
 	    }
         }
-
-      if (!pw)
-	{
-	  ip = inet_ntoa (addr.sin_addr);
-	  user = malloc (strlen (ip) + strlen (u) + 2);
-	  if (user)
-	    {
-	      sprintf (user, "%s!%s", u, ip);
-	      pw = getpwnam_virtual (user);
-	      free (user);
-	    }
-	}
     }
   return pw;
 }
