@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2003-2022 Free Software Foundation, Inc.
+   Copyright (C) 2003-2023 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
@@ -207,7 +207,7 @@ decode_boolean (char *str)
 
 /* Signal handling */
 
-typedef RETSIGTYPE (*signal_handler)(int);
+typedef void (*signal_handler)(int);
 
 static signal_handler
 set_signal_handler (int sig, signal_handler h)
@@ -235,7 +235,7 @@ spamd_abort (mu_sieve_machine_t mach, mu_stream_t *stream, signal_handler handle
 static int got_sigpipe;
 static signal_handler handler;
 
-static RETSIGTYPE
+static void
 sigpipe_handler (int sig MU_ARG_UNUSED)
 {
   got_sigpipe = 1;
