@@ -1,6 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2000, 2001, 2003, 2005, 2007, 2009, 2010, 2011
-   Free Software Foundation, Inc.
+   Copyright (C) 1999-2023 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -40,7 +39,7 @@
 #include <mailutils/sys/registrar.h>
 #include <mailutils/sys/url.h>
 
-/* We export url parsing and the initialisation of
+/* We export url parsing and the initialization of
    the mailbox, via the register entry/record.  */
 
 static struct _mu_record _pop_record =
