@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2003, 2007 Free Software Foundation, Inc.
+   Copyright (C) 2003-2023 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -12,9 +12,8 @@
    Lesser General Public License for more details.
 
    You should have received a copy of the GNU Lesser General
-   Public License along with this library; if not, write to the
-   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301 USA */
+   Public License along with this library.  If not, see
+   <http://www.gnu.org/licenses/>. */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -24,8 +23,9 @@
 #include <errno.h>
 #include <mailutils/errno.h>
 #include <mailutils/sys/pop3.h>
+#include <mailutils/list.h>
 
-/* Initialise a mu_pop3_t handle.  */
+/* Initialize a mu_pop3_t handle.  */
 
 int
 mu_pop3_create (mu_pop3_t *ppop3)
@@ -40,34 +40,25 @@ mu_pop3_create (mu_pop3_t *ppop3)
   if (pop3 == NULL)
     return ENOMEM;
 
-  /* Reserve space for the ack(nowledgement) response.
-     According to RFC 2449: The maximum length of the first line of a
-     command response (including the initial greeting) is unchanged at
-     512 octets (including the terminating CRLF).  */
-  pop3->ack.len = 512;
-  pop3->ack.buf = calloc (pop3->ack.len, 1);
-  if (pop3->ack.buf == NULL)
-    {
-      mu_pop3_destroy (&pop3);
-      return ENOMEM;
-    }
-  pop3->ack.ptr = pop3->ack.buf;
-
-  /* Reserve space for the data response/content.
-     RFC 2449 recommands 255, but we grow it as needed.  */
-  pop3->io.len = 255;
-  pop3->io.buf = calloc (pop3->io.len, 1);
-  if (pop3->io.buf == NULL)
-    {
-      mu_pop3_destroy (&pop3);
-      return ENOMEM;
-    }
-  pop3->io.ptr = pop3->io.buf;
-
   pop3->state = MU_POP3_NO_STATE; /* Init with no state.  */
   pop3->timeout = (10 * 60) * 100; /* The default Timeout is 10 minutes.  */
-  pop3->acknowledge = 0; /* No Ack received.  */
+  MU_POP3_FCLR (pop3, MU_POP3_ACK); /* No Ack received.  */
 
   *ppop3 = pop3;
   return 0; /* Okdoke.  */
 }
+
+int
+_mu_pop3_init (mu_pop3_t pop3)
+{
+  if (pop3 == NULL)
+    return EINVAL;
+  if (pop3->carrier == 0)
+    {
+      mu_list_destroy (&pop3->capa);
+      pop3->flags = 0;
+    }
+  return 0;
+}
+
+  
