@@ -1,6 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2001, 2004, 2007, 2010-2012, 2014-2017 Free
-   Software Foundation, Inc.
+   Copyright (C) 1999-2023 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -54,6 +53,7 @@ mu_pop3_top (mu_pop3_t pop3, unsigned msgno, unsigned int lines,
       pop3->state = MU_POP3_TOP_RX;
 
     case MU_POP3_TOP_RX:
+      status = 0;
       break;
 
       /* They must deal with the error first by reopening.  */
