@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2019 Free Software Foundation, Inc.
+   Copyright (C) 1999-2023 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -54,7 +54,7 @@ mail_previous (int argc, char **argv)
       int rc = msgset_parse (argc, argv, MSG_NODELETED|MSG_SILENT, &list);
       if (!rc)
 	{
-	  n = list->msg_part[0];
+	  n = msgset_msgno (list);
 	  msgset_free (list);
 	  if (util_get_message (mbox, n, &msg))
 	    return 1;
