@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2005-2012, 2014-2018 Free Software Foundation, Inc.
+   Copyright (C) 2005-2023 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -75,8 +75,14 @@ int
 burst_mime (mu_message_t msg)
 {
   size_t i, nparts;
+  int rc;
   
-  mu_message_get_num_parts (msg, &nparts);
+  rc = mu_message_get_num_parts (msg, &nparts);
+  if (rc)
+    {
+      mu_diag_funcall (MU_DIAG_ERR, "mu_message_get_num_parts", NULL, rc);
+      return rc;
+    }
 
   for (i = 1; i <= nparts; i++)
     {
@@ -325,7 +331,7 @@ flush_stream (struct burst_stream *bs, char *buf, size_t size)
     return;
   if (!bs->stream)
     {
-      if ((rc = mu_temp_file_stream_create (&bs->stream, NULL, 0))) 
+      if ((rc = mu_temp_stream_create (&bs->stream, 0))) 
 	{
 	  mu_error (_("Cannot open temporary file: %s"),
 		    mu_strerror (rc));
