@@ -58,14 +58,25 @@
 /* Pull parsers.  */
 #define YYPULL 1
 
+/* Substitute the type names.  */
+#define YYSTYPE         ALI_YYSTYPE
+#define YYLTYPE         ALI_YYLTYPE
+/* Substitute the variable and function names.  */
+#define yyparse         ali_yyparse
+#define yylex           ali_yylex
+#define yyerror         ali_yyerror
+#define yydebug         ali_yydebug
+#define yynerrs         ali_yynerrs
 
-
+#define yylval          ali_yylval
+#define yychar          ali_yychar
+#define yylloc          ali_yylloc
 
 /* Copy the first part of user declarations.  */
 #line 1 "mh_alias_gram.y" /* yacc.c:339  */
 
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2003-2021 Free Software Foundation, Inc.
+   Copyright (C) 2003-2023 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -167,11 +178,11 @@ static mu_list_t unix_group_to_list (char *name);
 static mu_list_t unix_gid_to_list (char *name);
 static mu_list_t unix_passwd_to_list (void);
 
-int ali_yyerror (char *s);
-int ali_yylex (void);
+int yyerror (char *s);
+int yylex (void);
 
 
-#line 175 "mh_alias_gram.c" /* yacc.c:339  */
+#line 186 "mh_alias_gram.c" /* yacc.c:339  */
 
 # ifndef YY_NULLPTR
 #  if defined __cplusplus && 201103L <= __cplusplus
@@ -190,34 +201,47 @@ int ali_yylex (void);
 #endif
 
 /* In a future release of Bison, this section will be replaced
-   by #include "y.tab.h".  */
-#ifndef YY_YY_Y_TAB_H_INCLUDED
-# define YY_YY_Y_TAB_H_INCLUDED
+   by #include "mh_alias_gram.h".  */
+#ifndef YY_ALI_YY_MH_ALIAS_GRAM_H_INCLUDED
+# define YY_ALI_YY_MH_ALIAS_GRAM_H_INCLUDED
 /* Debug traces.  */
-#ifndef YYDEBUG
-# define YYDEBUG 1
-#endif
+#ifndef ALI_YYDEBUG
+# if defined YYDEBUG
 #if YYDEBUG
+#   define ALI_YYDEBUG 1
+#  else
+#   define ALI_YYDEBUG 0
+#  endif
+# else /* ! defined YYDEBUG */
+#  define ALI_YYDEBUG 1
+# endif /* ! defined YYDEBUG */
+#endif  /* ! defined ALI_YYDEBUG */
+#if ALI_YYDEBUG
 extern int ali_yydebug;
 #endif
+/* "%code requires" blocks.  */
+#line 123 "mh_alias_gram.y" /* yacc.c:355  */
+
+#define ALI_YYLTYPE struct mu_locus_range
+#define yylloc ali_yylloc
+#define yylval ali_yylval
+
+#line 230 "mh_alias_gram.c" /* yacc.c:355  */
 
 /* Token type.  */
-#ifndef YYTOKENTYPE
-# define YYTOKENTYPE
-  enum yytokentype
+#ifndef ALI_YYTOKENTYPE
+# define ALI_YYTOKENTYPE
+  enum ali_yytokentype
   {
     EOL = 258,
     STRING = 259
   };
 #endif
-/* Tokens.  */
-#define EOL 258
-#define STRING 259
 
 /* Value type.  */
-#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
+#if ! defined ALI_YYSTYPE && ! defined ALI_YYSTYPE_IS_DECLARED
 
-union YYSTYPE
+union ALI_YYSTYPE
 {
 #line 110 "mh_alias_gram.y" /* yacc.c:355  */
 
@@ -225,38 +249,38 @@ union YYSTYPE
   mu_list_t list;
   struct mh_alias *alias;
 
-#line 229 "mh_alias_gram.c" /* yacc.c:355  */
+#line 253 "mh_alias_gram.c" /* yacc.c:355  */
 };
 
-typedef union YYSTYPE YYSTYPE;
-# define YYSTYPE_IS_TRIVIAL 1
-# define YYSTYPE_IS_DECLARED 1
+typedef union ALI_YYSTYPE ALI_YYSTYPE;
+# define ALI_YYSTYPE_IS_TRIVIAL 1
+# define ALI_YYSTYPE_IS_DECLARED 1
 #endif
 
 /* Location type.  */
-#if ! defined YYLTYPE && ! defined YYLTYPE_IS_DECLARED
-typedef struct YYLTYPE YYLTYPE;
-struct YYLTYPE
+#if ! defined ALI_YYLTYPE && ! defined ALI_YYLTYPE_IS_DECLARED
+typedef struct ALI_YYLTYPE ALI_YYLTYPE;
+struct ALI_YYLTYPE
 {
   int first_line;
   int first_column;
   int last_line;
   int last_column;
 };
-# define YYLTYPE_IS_DECLARED 1
-# define YYLTYPE_IS_TRIVIAL 1
+# define ALI_YYLTYPE_IS_DECLARED 1
+# define ALI_YYLTYPE_IS_TRIVIAL 1
 #endif
 
 
-extern YYSTYPE ali_yylval;
-extern YYLTYPE ali_yylloc;
+extern ALI_YYSTYPE ali_yylval;
+extern ALI_YYLTYPE ali_yylloc;
 int ali_yyparse (void);
 
-#endif /* !YY_YY_Y_TAB_H_INCLUDED  */
+#endif /* !YY_ALI_YY_MH_ALIAS_GRAM_H_INCLUDED  */
 
 /* Copy the second part of user declarations.  */
 
-#line 260 "mh_alias_gram.c" /* yacc.c:358  */
+#line 284 "mh_alias_gram.c" /* yacc.c:358  */
 
 #ifdef short
 # undef short
@@ -348,7 +372,7 @@ typedef short int yytype_int16;
 #endif
 
 #if defined __GNUC__ && 407 <= __GNUC__ * 100 + __GNUC_MINOR__
-/* Suppress an incorrect diagnostic about ali_yylval being uninitialized.  */
+/* Suppress an incorrect diagnostic about yylval being uninitialized.  */
 # define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN \
     _Pragma ("GCC diagnostic push") \
     _Pragma ("GCC diagnostic ignored \"-Wuninitialized\"")\
@@ -437,11 +461,11 @@ void free (void *); /* INFRINGES ON USER NAME SPACE */
 
 #if (! defined yyoverflow \
      && (! defined __cplusplus \
-         || (defined YYLTYPE_IS_TRIVIAL && YYLTYPE_IS_TRIVIAL \
-             && defined YYSTYPE_IS_TRIVIAL && YYSTYPE_IS_TRIVIAL)))
+         || (defined ALI_YYLTYPE_IS_TRIVIAL && ALI_YYLTYPE_IS_TRIVIAL \
+             && defined ALI_YYSTYPE_IS_TRIVIAL && ALI_YYSTYPE_IS_TRIVIAL)))
 
 /* A type that is properly aligned for any stack member.  */
-union ali_yyalloc
+union yyalloc
 {
   yytype_int16 yyss_alloc;
   YYSTYPE yyvs_alloc;
@@ -449,7 +473,7 @@ union ali_yyalloc
 };
 
 /* The size of the maximum gap between one aligned stack and the next.  */
-# define YYSTACK_GAP_MAXIMUM (sizeof (union ali_yyalloc) - 1)
+# define YYSTACK_GAP_MAXIMUM (sizeof (union yyalloc) - 1)
 
 /* The size of an array large to enough to hold all stacks, each with
    N elements.  */
@@ -512,7 +536,7 @@ union ali_yyalloc
 #define YYNSTATES  26
 
 /* YYTRANSLATE[YYX] -- Symbol number corresponding to YYX as returned
-   by ali_yylex, with out-of-bounds checking.  */
+   by yylex, with out-of-bounds checking.  */
 #define YYUNDEFTOK  2
 #define YYMAXUTOK   259
 
@@ -520,7 +544,7 @@ union ali_yyalloc
   ((unsigned int) (YYX) <= YYMAXUTOK ? yytranslate[YYX] : YYUNDEFTOK)
 
 /* YYTRANSLATE[TOKEN-NUM] -- Symbol number corresponding to TOKEN-NUM
-   as returned by ali_yylex, without out-of-bounds checking.  */
+   as returned by yylex, without out-of-bounds checking.  */
 static const yytype_uint8 yytranslate[] =
 {
        0,     2,     2,     2,     2,     2,     2,     2,     2,     2,
@@ -551,16 +575,16 @@ static const yytype_uint8 yytranslate[] =
        2,     2,     2,     2,     2,     2,     1,     2,     3,     4
 };
 
-#if YYDEBUG
+#if ALI_YYDEBUG
   /* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
 static const yytype_uint8 yyrline[] =
 {
-       0,   126,   126,   129,   133,   140,   143,   143,   151,   151,
-     161,   162,   167,   172,   178,   183,   190,   196,   201
+       0,   132,   132,   135,   139,   146,   149,   149,   157,   157,
+     167,   168,   173,   178,   184,   189,   196,   202,   207
 };
 #endif
 
-#if YYDEBUG || YYERROR_VERBOSE || 0
+#if ALI_YYDEBUG || YYERROR_VERBOSE || 0
 /* YYTNAME[SYMBOL-NUM] -- String name of the symbol SYMBOL-NUM.
    First, the terminals, then, starting at YYNTOKENS, nonterminals.  */
 static const char *const yytname[] =
@@ -593,7 +617,7 @@ static const yytype_uint16 yytoknum[] =
 
   /* YYPACT[STATE-NUM] -- Index in YYTABLE of the portion describing
      STATE-NUM.  */
-static const yytype_int8 ali_yypact[] =
+static const yytype_int8 yypact[] =
 {
       -3,     1,     2,     5,    -9,    -9,    -9,    -9,    -3,    -4,
       -4,    -9,    -9,     6,     7,    -9,    -9,    -1,    -9,     8,
@@ -625,13 +649,13 @@ static const yytype_int8 yydefgoto[] =
   /* YYTABLE[YYPACT[STATE-NUM]] -- What to do in state STATE-NUM.  If
      positive, shift that token.  If negative, reduce the rule whose
      number is the opposite.  If YYTABLE_NINF, syntax error.  */
-static const yytype_uint8 ali_yytable[] =
+static const yytype_uint8 yytable[] =
 {
       12,     1,     7,    13,    14,    15,     5,     6,     8,    23,
       21,    22,    24,    12,    20,    25,     0,     0,    11
 };
 
-static const yytype_int8 ali_yycheck[] =
+static const yytype_int8 yycheck[] =
 {
        4,     4,     0,     7,     8,     9,     5,     6,     3,    10,
        4,     4,     4,     4,    10,    23,    -1,    -1,     8
@@ -647,14 +671,14 @@ static const yytype_uint8 yystos[] =
 };
 
   /* YYR1[YYN] -- Symbol number of symbol that rule YYN derives.  */
-static const yytype_uint8 ali_yyr1[] =
+static const yytype_uint8 yyr1[] =
 {
        0,    11,    12,    13,    13,    14,    15,    14,    16,    14,
       17,    17,    17,    17,    18,    18,    19,    20,    20
 };
 
   /* YYR2[YYN] -- Number of symbols on the right hand side of rule YYN.  */
-static const yytype_uint8 ali_yyr2[] =
+static const yytype_uint8 yyr2[] =
 {
        0,     2,     1,     1,     3,     0,     0,     4,     0,     4,
        1,     2,     2,     1,     1,     3,     1,     1,     2
@@ -662,7 +686,7 @@ static const yytype_uint8 ali_yyr2[] =
 
 
 #define yyerrok         (yyerrstatus = 0)
-#define yyclearin       (ali_yychar = YYEMPTY)
+#define yyclearin       (yychar = YYEMPTY)
 #define YYEMPTY         (-2)
 #define YYEOF           0
 
@@ -675,17 +699,17 @@ static const yytype_uint8 ali_yyr2[] =
 
 #define YYBACKUP(Token, Value)                                  \
 do                                                              \
-  if (ali_yychar == YYEMPTY)                                        \
+  if (yychar == YYEMPTY)                                        \
     {                                                           \
-      ali_yychar = (Token);                                         \
-      ali_yylval = (Value);                                         \
-      YYPOPSTACK (ali_yylen);                                       \
-      ali_yystate = *yyssp;                                         \
+      yychar = (Token);                                         \
+      yylval = (Value);                                         \
+      YYPOPSTACK (yylen);                                       \
+      yystate = *yyssp;                                         \
       goto yybackup;                                            \
     }                                                           \
   else                                                          \
     {                                                           \
-      ali_yyerror (YY_("syntax error: cannot back up")); \
+      yyerror (YY_("syntax error: cannot back up")); \
       YYERROR;                                                  \
     }                                                           \
 while (0)
@@ -723,7 +747,7 @@ while (0)
 
 
 /* Enable debugging if requested.  */
-#if YYDEBUG
+#if ALI_YYDEBUG
 
 # ifndef YYFPRINTF
 #  include <stdio.h> /* INFRINGES ON USER NAME SPACE */
@@ -732,7 +756,7 @@ while (0)
 
 # define YYDPRINTF(Args)                        \
 do {                                            \
-  if (ali_yydebug)                                  \
+  if (yydebug)                                  \
     YYFPRINTF Args;                             \
 } while (0)
 
@@ -742,7 +766,7 @@ do {                                            \
    we won't break user code: when these are the locations we know.  */
 
 #ifndef YY_LOCATION_PRINT
-# if defined YYLTYPE_IS_TRIVIAL && YYLTYPE_IS_TRIVIAL
+# if defined ALI_YYLTYPE_IS_TRIVIAL && ALI_YYLTYPE_IS_TRIVIAL
 
 /* Print *YYLOCP on YYO.  Private, do not rely on its existence. */
 
@@ -783,7 +807,7 @@ yy_location_print_ (FILE *yyo, YYLTYPE const * const yylocp)
 
 # define YY_SYMBOL_PRINT(Title, Type, Value, Location)                    \
 do {                                                                      \
-  if (ali_yydebug)                                                            \
+  if (yydebug)                                                            \
     {                                                                     \
       YYFPRINTF (stderr, "%s ", Title);                                   \
       yy_symbol_print (stderr,                                            \
@@ -848,7 +872,7 @@ yy_stack_print (yytype_int16 *yybottom, yytype_int16 *yytop)
 
 # define YY_STACK_PRINT(Bottom, Top)                            \
 do {                                                            \
-  if (ali_yydebug)                                                  \
+  if (yydebug)                                                  \
     yy_stack_print ((Bottom), (Top));                           \
 } while (0)
 
@@ -858,13 +882,13 @@ do {                                                            \
 `------------------------------------------------*/
 
 static void
-yy_reduce_print (yytype_int16 *yyssp, YYSTYPE *yyvsp, YYLTYPE *yylsp, int ali_yyrule)
+yy_reduce_print (yytype_int16 *yyssp, YYSTYPE *yyvsp, YYLTYPE *yylsp, int yyrule)
 {
-  unsigned long int yylno = yyrline[ali_yyrule];
-  int yynrhs = ali_yyr2[ali_yyrule];
+  unsigned long int yylno = yyrline[yyrule];
+  int yynrhs = yyr2[yyrule];
   int yyi;
   YYFPRINTF (stderr, "Reducing stack by rule %d (line %lu):\n",
-             ali_yyrule - 1, yylno);
+             yyrule - 1, yylno);
   /* The symbols being reduced.  */
   for (yyi = 0; yyi < yynrhs; yyi++)
     {
@@ -879,19 +903,19 @@ yy_reduce_print (yytype_int16 *yyssp, YYSTYPE *yyvsp, YYLTYPE *yylsp, int ali_yy
 
 # define YY_REDUCE_PRINT(Rule)          \
 do {                                    \
-  if (ali_yydebug)                          \
+  if (yydebug)                          \
     yy_reduce_print (yyssp, yyvsp, yylsp, Rule); \
 } while (0)
 
 /* Nonzero means print parse trace.  It is left uninitialized so that
    multiple parsers can coexist.  */
-int ali_yydebug;
-#else /* !YYDEBUG */
+int yydebug;
+#else /* !ALI_YYDEBUG */
 # define YYDPRINTF(Args)
 # define YY_SYMBOL_PRINT(Title, Type, Value, Location)
 # define YY_STACK_PRINT(Bottom, Top)
 # define YY_REDUCE_PRINT(Rule)
-#endif /* !YYDEBUG */
+#endif /* !ALI_YYDEBUG */
 
 
 /* YYINITDEPTH -- initial size of the parser's stacks.  */
@@ -921,10 +945,10 @@ int ali_yydebug;
 static YYSIZE_T
 yystrlen (const char *yystr)
 {
-  YYSIZE_T ali_yylen;
-  for (ali_yylen = 0; yystr[ali_yylen]; ali_yylen++)
+  YYSIZE_T yylen;
+  for (yylen = 0; yystr[yylen]; yylen++)
     continue;
-  return ali_yylen;
+  return yylen;
 }
 #  endif
 # endif
@@ -939,9 +963,9 @@ static char *
 yystpcpy (char *yydest, const char *yysrc)
 {
   char *yyd = yydest;
-  const char *ali_yys = yysrc;
+  const char *yys = yysrc;
 
-  while ((*yyd++ = *ali_yys++) != '\0')
+  while ((*yyd++ = *yys++) != '\0')
     continue;
 
   return yyd - 1;
@@ -951,7 +975,7 @@ yystpcpy (char *yydest, const char *yysrc)
 
 # ifndef yytnamerr
 /* Copy to YYRES the contents of YYSTR after stripping away unnecessary
-   quotes and backslashes, so that it's suitable for ali_yyerror.  The
+   quotes and backslashes, so that it's suitable for yyerror.  The
    heuristic is that double-quoting is unnecessary unless the string
    contains an apostrophe, a comma, or backslash (other than
    backslash-backslash).  YYSTR is taken from yytname.  If YYRES is
@@ -1025,7 +1049,7 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
        the only way this function was invoked is if the default action
        is an error action.  In that case, don't check for expected
        tokens because there are none.
-     - The only way there can be no lookahead present (in ali_yychar) is if
+     - The only way there can be no lookahead present (in yychar) is if
        this state is a consistent state with a default action.  Thus,
        detecting the absence of a lookahead is sufficient to determine
        that there is no unexpected or expected token to report.  In that
@@ -1033,7 +1057,7 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
      - Don't assume there isn't a lookahead just because this state is a
        consistent state with a default action.  There might have been a
        previous inconsistent state, consistent state with a non-default
-       action, or user semantic action that manipulated ali_yychar.
+       action, or user semantic action that manipulated yychar.
      - Of course, the expected token list depends on states to have
        correct lookahead information, and it depends on the parser not
        to perform extra reductions after fetching a lookahead from the
@@ -1045,7 +1069,7 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
   */
   if (yytoken != YYEMPTY)
     {
-      int yyn = ali_yypact[*yyssp];
+      int yyn = yypact[*yyssp];
       yyarg[yycount++] = yytname[yytoken];
       if (!yypact_value_is_default (yyn))
         {
@@ -1053,14 +1077,14 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
              YYCHECK.  In other words, skip the first -YYN actions for
              this state because they are default actions.  */
           int yyxbegin = yyn < 0 ? -yyn : 0;
-          /* Stay within bounds of both ali_yycheck and yytname.  */
+          /* Stay within bounds of both yycheck and yytname.  */
           int yychecklim = YYLAST - yyn + 1;
           int yyxend = yychecklim < YYNTOKENS ? yychecklim : YYNTOKENS;
           int yyx;
 
           for (yyx = yyxbegin; yyx < yyxend; ++yyx)
-            if (ali_yycheck[yyx + yyn] == yyx && yyx != YYTERROR
-                && !yytable_value_is_error (ali_yytable[yyx + yyn]))
+            if (yycheck[yyx + yyn] == yyx && yyx != YYTERROR
+                && !yytable_value_is_error (yytable[yyx + yyn]))
               {
                 if (yycount == YYERROR_VERBOSE_ARGS_MAXIMUM)
                   {
@@ -1155,28 +1179,28 @@ yydestruct (const char *yymsg, int yytype, YYSTYPE *yyvaluep, YYLTYPE *yylocatio
 
 
 /* The lookahead symbol.  */
-int ali_yychar;
+int yychar;
 
 /* The semantic value of the lookahead symbol.  */
-YYSTYPE ali_yylval;
+YYSTYPE yylval;
 /* Location data for the lookahead symbol.  */
-YYLTYPE ali_yylloc
-# if defined YYLTYPE_IS_TRIVIAL && YYLTYPE_IS_TRIVIAL
+YYLTYPE yylloc
+# if defined ALI_YYLTYPE_IS_TRIVIAL && ALI_YYLTYPE_IS_TRIVIAL
   = { 1, 1, 1, 1 }
 # endif
 ;
 /* Number of syntax errors so far.  */
-int ali_yynerrs;
+int yynerrs;
 
 
 /*----------.
-| ali_yyparse.  |
+| yyparse.  |
 `----------*/
 
 int
-ali_yyparse (void)
+yyparse (void)
 {
-    int ali_yystate;
+    int yystate;
     /* Number of tokens to shift before error messages enabled.  */
     int yyerrstatus;
 
@@ -1214,7 +1238,7 @@ ali_yyparse (void)
   int yytoken = 0;
   /* The variables used to return semantic value and location from the
      action routines.  */
-  YYSTYPE ali_yyval;
+  YYSTYPE yyval;
   YYLTYPE yyloc;
 
 #if YYERROR_VERBOSE
@@ -1228,7 +1252,7 @@ ali_yyparse (void)
 
   /* The number of symbols on the RHS of the reduced rule.
      Keep to zero when no symbol should be popped.  */
-  int ali_yylen = 0;
+  int yylen = 0;
 
   yyssp = yyss = yyssa;
   yyvsp = yyvs = yyvsa;
@@ -1237,15 +1261,15 @@ ali_yyparse (void)
 
   YYDPRINTF ((stderr, "Starting parse\n"));
 
-  ali_yystate = 0;
+  yystate = 0;
   yyerrstatus = 0;
-  ali_yynerrs = 0;
-  ali_yychar = YYEMPTY; /* Cause a token to be read.  */
-  yylsp[0] = ali_yylloc;
+  yynerrs = 0;
+  yychar = YYEMPTY; /* Cause a token to be read.  */
+  yylsp[0] = yylloc;
   goto yysetstate;
 
 /*------------------------------------------------------------.
-| yynewstate -- Push a new state, which is found in ali_yystate.  |
+| yynewstate -- Push a new state, which is found in yystate.  |
 `------------------------------------------------------------*/
  yynewstate:
   /* In all cases, when you get here, the value and location stacks
@@ -1253,7 +1277,7 @@ ali_yyparse (void)
   yyssp++;
 
  yysetstate:
-  *yyssp = ali_yystate;
+  *yyssp = yystate;
 
   if (yyss + yystacksize - 1 <= yyssp)
     {
@@ -1296,8 +1320,8 @@ ali_yyparse (void)
 
       {
         yytype_int16 *yyss1 = yyss;
-        union ali_yyalloc *yyptr =
-          (union ali_yyalloc *) YYSTACK_ALLOC (YYSTACK_BYTES (yystacksize));
+        union yyalloc *yyptr =
+          (union yyalloc *) YYSTACK_ALLOC (YYSTACK_BYTES (yystacksize));
         if (! yyptr)
           goto yyexhaustedlab;
         YYSTACK_RELOCATE (yyss_alloc, yyss);
@@ -1321,9 +1345,9 @@ ali_yyparse (void)
         YYABORT;
     }
 
-  YYDPRINTF ((stderr, "Entering state %d\n", ali_yystate));
+  YYDPRINTF ((stderr, "Entering state %d\n", yystate));
 
-  if (ali_yystate == YYFINAL)
+  if (yystate == YYFINAL)
     YYACCEPT;
 
   goto yybackup;
@@ -1337,36 +1361,36 @@ yybackup:
      lookahead token if we need one and don't already have one.  */
 
   /* First try to decide what to do without reference to lookahead token.  */
-  yyn = ali_yypact[ali_yystate];
+  yyn = yypact[yystate];
   if (yypact_value_is_default (yyn))
     goto yydefault;
 
   /* Not known => get a lookahead token if don't already have one.  */
 
   /* YYCHAR is either YYEMPTY or YYEOF or a valid lookahead symbol.  */
-  if (ali_yychar == YYEMPTY)
+  if (yychar == YYEMPTY)
     {
       YYDPRINTF ((stderr, "Reading a token: "));
-      ali_yychar = ali_yylex ();
+      yychar = yylex ();
     }
 
-  if (ali_yychar <= YYEOF)
+  if (yychar <= YYEOF)
     {
-      ali_yychar = yytoken = YYEOF;
+      yychar = yytoken = YYEOF;
       YYDPRINTF ((stderr, "Now at end of input.\n"));
     }
   else
     {
-      yytoken = YYTRANSLATE (ali_yychar);
-      YY_SYMBOL_PRINT ("Next token is", yytoken, &ali_yylval, &ali_yylloc);
+      yytoken = YYTRANSLATE (yychar);
+      YY_SYMBOL_PRINT ("Next token is", yytoken, &yylval, &yylloc);
     }
 
   /* If the proper action on seeing token YYTOKEN is to reduce or to
      detect an error, take that action.  */
   yyn += yytoken;
-  if (yyn < 0 || YYLAST < yyn || ali_yycheck[yyn] != yytoken)
+  if (yyn < 0 || YYLAST < yyn || yycheck[yyn] != yytoken)
     goto yydefault;
-  yyn = ali_yytable[yyn];
+  yyn = yytable[yyn];
   if (yyn <= 0)
     {
       if (yytable_value_is_error (yyn))
@@ -1381,16 +1405,16 @@ yybackup:
     yyerrstatus--;
 
   /* Shift the lookahead token.  */
-  YY_SYMBOL_PRINT ("Shifting", yytoken, &ali_yylval, &ali_yylloc);
+  YY_SYMBOL_PRINT ("Shifting", yytoken, &yylval, &yylloc);
 
   /* Discard the shifted token.  */
-  ali_yychar = YYEMPTY;
+  yychar = YYEMPTY;
 
-  ali_yystate = yyn;
+  yystate = yyn;
   YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
-  *++yyvsp = ali_yylval;
+  *++yyvsp = yylval;
   YY_IGNORE_MAYBE_UNINITIALIZED_END
-  *++yylsp = ali_yylloc;
+  *++yylsp = yylloc;
   goto yynewstate;
 
 
@@ -1398,7 +1422,7 @@ yybackup:
 | yydefault -- do the default action for the current state.  |
 `-----------------------------------------------------------*/
 yydefault:
-  yyn = yydefact[ali_yystate];
+  yyn = yydefact[yystate];
   if (yyn == 0)
     goto yyerrlab;
   goto yyreduce;
@@ -1409,7 +1433,7 @@ yydefault:
 `-----------------------------*/
 yyreduce:
   /* yyn is the number of a rule to reduce with.  */
-  ali_yylen = ali_yyr2[yyn];
+  yylen = yyr2[yyn];
 
   /* If YYLEN is nonzero, implement the default value of the action:
      '$$ = $1'.
@@ -1419,178 +1443,178 @@ yyreduce:
      users should not rely upon it.  Assigning to YYVAL
      unconditionally makes the parser a bit smaller, and it avoids a
      GCC warning that YYVAL may be used uninitialized.  */
-  ali_yyval = yyvsp[1-ali_yylen];
+  yyval = yyvsp[1-yylen];
 
   /* Default location.  */
-  YYLLOC_DEFAULT (yyloc, (yylsp - ali_yylen), ali_yylen);
+  YYLLOC_DEFAULT (yyloc, (yylsp - yylen), yylen);
   YY_REDUCE_PRINT (yyn);
   switch (yyn)
     {
         case 3:
-#line 130 "mh_alias_gram.y" /* yacc.c:1646  */
+#line 136 "mh_alias_gram.y" /* yacc.c:1646  */
     {
 		 ali_append ((yyvsp[0].alias));
 	       }
-#line 1435 "mh_alias_gram.c" /* yacc.c:1646  */
+#line 1459 "mh_alias_gram.c" /* yacc.c:1646  */
     break;
 
   case 4:
-#line 134 "mh_alias_gram.y" /* yacc.c:1646  */
+#line 140 "mh_alias_gram.y" /* yacc.c:1646  */
     {
 		 ali_append ((yyvsp[0].alias));
 	       }
-#line 1443 "mh_alias_gram.c" /* yacc.c:1646  */
+#line 1467 "mh_alias_gram.c" /* yacc.c:1646  */
     break;
 
   case 5:
-#line 140 "mh_alias_gram.y" /* yacc.c:1646  */
+#line 146 "mh_alias_gram.y" /* yacc.c:1646  */
     {
-		 (ali_yyval.alias) = NULL;
+		 (yyval.alias) = NULL;
 	       }
-#line 1451 "mh_alias_gram.c" /* yacc.c:1646  */
-    break;
-
-  case 6:
-#line 143 "mh_alias_gram.y" /* yacc.c:1646  */
-    { ali_verbatim (1); }
-#line 1457 "mh_alias_gram.c" /* yacc.c:1646  */
-    break;
-
-  case 7:
-#line 144 "mh_alias_gram.y" /* yacc.c:1646  */
-    {
-		 ali_verbatim (0);
-		 (ali_yyval.alias) = mu_alloc (sizeof (*(ali_yyval.alias)));
-		 (ali_yyval.alias)->name = (yyvsp[-3].string);
-		 (ali_yyval.alias)->rcpt_list = (yyvsp[0].list);
-		 (ali_yyval.alias)->inclusive = 0;
-	       }
-#line 1469 "mh_alias_gram.c" /* yacc.c:1646  */
-    break;
-
-  case 8:
-#line 151 "mh_alias_gram.y" /* yacc.c:1646  */
-    { ali_verbatim (1); }
 #line 1475 "mh_alias_gram.c" /* yacc.c:1646  */
     break;
 
-  case 9:
-#line 152 "mh_alias_gram.y" /* yacc.c:1646  */
+  case 6:
+#line 149 "mh_alias_gram.y" /* yacc.c:1646  */
+    { ali_verbatim (1); }
+#line 1481 "mh_alias_gram.c" /* yacc.c:1646  */
+    break;
+
+  case 7:
+#line 150 "mh_alias_gram.y" /* yacc.c:1646  */
     {
 		 ali_verbatim (0);
-		 (ali_yyval.alias) = mu_alloc (sizeof (*(ali_yyval.alias)));
-		 (ali_yyval.alias)->name = (yyvsp[-3].string);
-		 (ali_yyval.alias)->rcpt_list = (yyvsp[0].list);
-		 (ali_yyval.alias)->inclusive = 1;
+		 (yyval.alias) = mu_alloc (sizeof (*(yyval.alias)));
+		 (yyval.alias)->name = (yyvsp[-3].string);
+		 (yyval.alias)->rcpt_list = (yyvsp[0].list);
+		 (yyval.alias)->inclusive = 0;
 	       }
-#line 1487 "mh_alias_gram.c" /* yacc.c:1646  */
+#line 1493 "mh_alias_gram.c" /* yacc.c:1646  */
+    break;
+
+  case 8:
+#line 157 "mh_alias_gram.y" /* yacc.c:1646  */
+    { ali_verbatim (1); }
+#line 1499 "mh_alias_gram.c" /* yacc.c:1646  */
+    break;
+
+  case 9:
+#line 158 "mh_alias_gram.y" /* yacc.c:1646  */
+    {
+		 ali_verbatim (0);
+		 (yyval.alias) = mu_alloc (sizeof (*(yyval.alias)));
+		 (yyval.alias)->name = (yyvsp[-3].string);
+		 (yyval.alias)->rcpt_list = (yyvsp[0].list);
+		 (yyval.alias)->inclusive = 1;
+	       }
+#line 1511 "mh_alias_gram.c" /* yacc.c:1646  */
     break;
 
   case 11:
-#line 163 "mh_alias_gram.y" /* yacc.c:1646  */
+#line 169 "mh_alias_gram.y" /* yacc.c:1646  */
     {
-		 (ali_yyval.list) = unix_group_to_list ((yyvsp[0].string));
+		 (yyval.list) = unix_group_to_list ((yyvsp[0].string));
 		 free ((yyvsp[0].string));
 	       }
-#line 1496 "mh_alias_gram.c" /* yacc.c:1646  */
+#line 1520 "mh_alias_gram.c" /* yacc.c:1646  */
     break;
 
   case 12:
-#line 168 "mh_alias_gram.y" /* yacc.c:1646  */
+#line 174 "mh_alias_gram.y" /* yacc.c:1646  */
     {
-		 (ali_yyval.list) = unix_gid_to_list ((yyvsp[0].string));
+		 (yyval.list) = unix_gid_to_list ((yyvsp[0].string));
 		 free ((yyvsp[0].string));
 	       }
-#line 1505 "mh_alias_gram.c" /* yacc.c:1646  */
+#line 1529 "mh_alias_gram.c" /* yacc.c:1646  */
     break;
 
   case 13:
-#line 173 "mh_alias_gram.y" /* yacc.c:1646  */
+#line 179 "mh_alias_gram.y" /* yacc.c:1646  */
     {
-		 (ali_yyval.list) = unix_passwd_to_list ();
+		 (yyval.list) = unix_passwd_to_list ();
 	       }
-#line 1513 "mh_alias_gram.c" /* yacc.c:1646  */
+#line 1537 "mh_alias_gram.c" /* yacc.c:1646  */
     break;
 
   case 14:
-#line 179 "mh_alias_gram.y" /* yacc.c:1646  */
+#line 185 "mh_alias_gram.y" /* yacc.c:1646  */
     {
-		 (ali_yyval.list) = list_create_or_die ();
-		 mu_list_append ((ali_yyval.list), (yyvsp[0].string));
+		 (yyval.list) = list_create_or_die ();
+		 mu_list_append ((yyval.list), (yyvsp[0].string));
 	       }
-#line 1522 "mh_alias_gram.c" /* yacc.c:1646  */
+#line 1546 "mh_alias_gram.c" /* yacc.c:1646  */
     break;
 
   case 15:
-#line 184 "mh_alias_gram.y" /* yacc.c:1646  */
+#line 190 "mh_alias_gram.y" /* yacc.c:1646  */
     {
 		 mu_list_append ((yyvsp[-2].list), (yyvsp[0].string));
-		 (ali_yyval.list) = (yyvsp[-2].list);
+		 (yyval.list) = (yyvsp[-2].list);
 	       }
-#line 1531 "mh_alias_gram.c" /* yacc.c:1646  */
+#line 1555 "mh_alias_gram.c" /* yacc.c:1646  */
     break;
 
   case 16:
-#line 191 "mh_alias_gram.y" /* yacc.c:1646  */
+#line 197 "mh_alias_gram.y" /* yacc.c:1646  */
     {
-		 (ali_yyval.string) = ali_list_to_string (&(yyvsp[0].list));
+		 (yyval.string) = ali_list_to_string (&(yyvsp[0].list));
 	       }
-#line 1539 "mh_alias_gram.c" /* yacc.c:1646  */
+#line 1563 "mh_alias_gram.c" /* yacc.c:1646  */
     break;
 
   case 17:
-#line 197 "mh_alias_gram.y" /* yacc.c:1646  */
+#line 203 "mh_alias_gram.y" /* yacc.c:1646  */
     {
-		 mu_list_create(&(ali_yyval.list));
-		 mu_list_append((ali_yyval.list), (yyvsp[0].string));
+		 mu_list_create(&(yyval.list));
+		 mu_list_append((yyval.list), (yyvsp[0].string));
 	       }
-#line 1548 "mh_alias_gram.c" /* yacc.c:1646  */
+#line 1572 "mh_alias_gram.c" /* yacc.c:1646  */
     break;
 
   case 18:
-#line 202 "mh_alias_gram.y" /* yacc.c:1646  */
+#line 208 "mh_alias_gram.y" /* yacc.c:1646  */
     {
 		 mu_list_append((yyvsp[-1].list), (yyvsp[0].string));
-		 (ali_yyval.list) = (yyvsp[-1].list);
+		 (yyval.list) = (yyvsp[-1].list);
 	       }
-#line 1557 "mh_alias_gram.c" /* yacc.c:1646  */
+#line 1581 "mh_alias_gram.c" /* yacc.c:1646  */
     break;
 
 
-#line 1561 "mh_alias_gram.c" /* yacc.c:1646  */
+#line 1585 "mh_alias_gram.c" /* yacc.c:1646  */
       default: break;
     }
-  /* User semantic actions sometimes alter ali_yychar, and that requires
+  /* User semantic actions sometimes alter yychar, and that requires
      that yytoken be updated with the new translation.  We take the
      approach of translating immediately before every use of yytoken.
      One alternative is translating here after every semantic action,
      but that translation would be missed if the semantic action invokes
-     YYABORT, YYACCEPT, or YYERROR immediately after altering ali_yychar or
+     YYABORT, YYACCEPT, or YYERROR immediately after altering yychar or
      if it invokes YYBACKUP.  In the case of YYABORT or YYACCEPT, an
      incorrect destructor might then be invoked immediately.  In the
      case of YYERROR or YYBACKUP, subsequent parser actions might lead
      to an incorrect destructor call or verbose syntax error message
      before the lookahead is translated.  */
-  YY_SYMBOL_PRINT ("-> $$ =", ali_yyr1[yyn], &ali_yyval, &yyloc);
+  YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
 
-  YYPOPSTACK (ali_yylen);
-  ali_yylen = 0;
+  YYPOPSTACK (yylen);
+  yylen = 0;
   YY_STACK_PRINT (yyss, yyssp);
 
-  *++yyvsp = ali_yyval;
+  *++yyvsp = yyval;
   *++yylsp = yyloc;
 
   /* Now 'shift' the result of the reduction.  Determine what state
      that goes to, based on the state we popped back to and the rule
      number reduced by.  */
 
-  yyn = ali_yyr1[yyn];
+  yyn = yyr1[yyn];
 
-  ali_yystate = yypgoto[yyn - YYNTOKENS] + *yyssp;
-  if (0 <= ali_yystate && ali_yystate <= YYLAST && ali_yycheck[ali_yystate] == *yyssp)
-    ali_yystate = ali_yytable[ali_yystate];
+  yystate = yypgoto[yyn - YYNTOKENS] + *yyssp;
+  if (0 <= yystate && yystate <= YYLAST && yycheck[yystate] == *yyssp)
+    yystate = yytable[yystate];
   else
-    ali_yystate = yydefgoto[yyn - YYNTOKENS];
+    yystate = yydefgoto[yyn - YYNTOKENS];
 
   goto yynewstate;
 
@@ -1601,14 +1625,14 @@ yyreduce:
 yyerrlab:
   /* Make sure we have latest lookahead translation.  See comments at
      user semantic actions for why this is necessary.  */
-  yytoken = ali_yychar == YYEMPTY ? YYEMPTY : YYTRANSLATE (ali_yychar);
+  yytoken = yychar == YYEMPTY ? YYEMPTY : YYTRANSLATE (yychar);
 
   /* If not already recovering from an error, report this error.  */
   if (!yyerrstatus)
     {
-      ++ali_yynerrs;
+      ++yynerrs;
 #if ! YYERROR_VERBOSE
-      ali_yyerror (YY_("syntax error"));
+      yyerror (YY_("syntax error"));
 #else
 # define YYSYNTAX_ERROR yysyntax_error (&yymsg_alloc, &yymsg, \
                                         yyssp, yytoken)
@@ -1635,7 +1659,7 @@ yyerrlab:
                 yymsgp = yymsg;
               }
           }
-        ali_yyerror (yymsgp);
+        yyerror (yymsgp);
         if (yysyntax_error_status == 2)
           goto yyexhaustedlab;
       }
@@ -1643,24 +1667,24 @@ yyerrlab:
 #endif
     }
 
-  yyerror_range[1] = ali_yylloc;
+  yyerror_range[1] = yylloc;
 
   if (yyerrstatus == 3)
     {
       /* If just tried and failed to reuse lookahead token after an
          error, discard it.  */
 
-      if (ali_yychar <= YYEOF)
+      if (yychar <= YYEOF)
         {
           /* Return failure if at end of input.  */
-          if (ali_yychar == YYEOF)
+          if (yychar == YYEOF)
             YYABORT;
         }
       else
         {
           yydestruct ("Error: discarding",
-                      yytoken, &ali_yylval, &ali_yylloc);
-          ali_yychar = YYEMPTY;
+                      yytoken, &yylval, &yylloc);
+          yychar = YYEMPTY;
         }
     }
 
@@ -1680,13 +1704,13 @@ yyerrorlab:
   if (/*CONSTCOND*/ 0)
      goto yyerrorlab;
 
-  yyerror_range[1] = yylsp[1-ali_yylen];
+  yyerror_range[1] = yylsp[1-yylen];
   /* Do not reclaim the symbols of the rule whose action triggered
      this YYERROR.  */
-  YYPOPSTACK (ali_yylen);
-  ali_yylen = 0;
+  YYPOPSTACK (yylen);
+  yylen = 0;
   YY_STACK_PRINT (yyss, yyssp);
-  ali_yystate = *yyssp;
+  yystate = *yyssp;
   goto yyerrlab1;
 
 
@@ -1698,13 +1722,13 @@ yyerrlab1:
 
   for (;;)
     {
-      yyn = ali_yypact[ali_yystate];
+      yyn = yypact[yystate];
       if (!yypact_value_is_default (yyn))
         {
           yyn += YYTERROR;
-          if (0 <= yyn && yyn <= YYLAST && ali_yycheck[yyn] == YYTERROR)
+          if (0 <= yyn && yyn <= YYLAST && yycheck[yyn] == YYTERROR)
             {
-              yyn = ali_yytable[yyn];
+              yyn = yytable[yyn];
               if (0 < yyn)
                 break;
             }
@@ -1716,17 +1740,17 @@ yyerrlab1:
 
       yyerror_range[1] = *yylsp;
       yydestruct ("Error: popping",
-                  yystos[ali_yystate], yyvsp, yylsp);
+                  yystos[yystate], yyvsp, yylsp);
       YYPOPSTACK (1);
-      ali_yystate = *yyssp;
+      yystate = *yyssp;
       YY_STACK_PRINT (yyss, yyssp);
     }
 
   YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
-  *++yyvsp = ali_yylval;
+  *++yyvsp = yylval;
   YY_IGNORE_MAYBE_UNINITIALIZED_END
 
-  yyerror_range[2] = ali_yylloc;
+  yyerror_range[2] = yylloc;
   /* Using YYLLOC is tempting, but would change the location of
      the lookahead.  YYLOC is available though.  */
   YYLLOC_DEFAULT (yyloc, yyerror_range, 2);
@@ -1735,7 +1759,7 @@ yyerrlab1:
   /* Shift the error token.  */
   YY_SYMBOL_PRINT ("Shifting", yystos[yyn], yyvsp, yylsp);
 
-  ali_yystate = yyn;
+  yystate = yyn;
   goto yynewstate;
 
 
@@ -1758,23 +1782,23 @@ yyabortlab:
 | yyexhaustedlab -- memory exhaustion comes here.  |
 `-------------------------------------------------*/
 yyexhaustedlab:
-  ali_yyerror (YY_("memory exhausted"));
+  yyerror (YY_("memory exhausted"));
   yyresult = 2;
   /* Fall through.  */
 #endif
 
 yyreturn:
-  if (ali_yychar != YYEMPTY)
+  if (yychar != YYEMPTY)
     {
       /* Make sure we have latest lookahead translation.  See comments at
          user semantic actions for why this is necessary.  */
-      yytoken = YYTRANSLATE (ali_yychar);
+      yytoken = YYTRANSLATE (yychar);
       yydestruct ("Cleanup: discarding lookahead",
-                  yytoken, &ali_yylval, &ali_yylloc);
+                  yytoken, &yylval, &yylloc);
     }
   /* Do not reclaim the symbols of the rule whose action triggered
      this YYABORT or YYACCEPT.  */
-  YYPOPSTACK (ali_yylen);
+  YYPOPSTACK (yylen);
   YY_STACK_PRINT (yyss, yyssp);
   while (yyssp != yyss)
     {
@@ -1792,9 +1816,16 @@ yyreturn:
 #endif
   return yyresult;
 }
-#line 208 "mh_alias_gram.y" /* yacc.c:1906  */
+#line 214 "mh_alias_gram.y" /* yacc.c:1906  */
 
 
+int
+yyerror (char *s)
+{
+  mu_error ("%s", s);
+  return 0;
+}
+
 static mu_list_t
 ali_list_dup (mu_list_t src)
 {
