@@ -1,6 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2002, 2005, 2006, 2007, 2008,
-   2009 Free Software Foundation, Inc.
+   Copyright (C) 2002-2023 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -13,9 +12,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with GNU Mailutils; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
-   MA 02110-1301 USA */
+   along with GNU Mailutils.  If not, see <http://www.gnu.org/licenses/>. */
 
 /* MH rmf command */
 
@@ -30,80 +27,40 @@
 
 #include <dirent.h>
 
-const char *program_version = "rmf (" PACKAGE_STRING ")";
-static char doc[] = N_("GNU MH rmf")"\v"
-N_("Use -help to obtain the list of traditional MH options.");
-static char args_doc[] = N_("[+folder]");
-
-/* GNU options */
-static struct argp_option options[] = {
-  {"folder",  ARG_FOLDER, N_("FOLDER"), 0,
-   N_("specify the folder to delete")},
-  {"interactive", ARG_INTERACTIVE, N_("BOOL"), OPTION_ARG_OPTIONAL,
-    N_("interactive mode: ask for confirmation before removing each folder")},
-  {"nointeractive", ARG_NOINTERACTIVE, NULL, OPTION_HIDDEN, ""},
-  {"recursive", ARG_RECURSIVE, NULL, 0,
-   N_("recursively delete all subfolders")},
-  {"norecursive", ARG_NORECURSIVE, NULL, OPTION_HIDDEN, ""},
-  {"license", ARG_LICENSE, 0,      0,
-   N_("display software license"), -1},
-  { 0 }
-};
-
-/* Traditional MH options */
-struct mh_option mh_option[] = {
-  {"interactive", 1, MH_OPT_BOOL, NULL},
-  { 0 }
-};
+static char prog_doc[] = N_("Remove a GNU MH folder");
 
 int explicit_folder; /* Was the folder explicitly given */
 int interactive; /* Ask for confirmation before deleting */
-int recurse;     /* Recursively process all the sub-directories */
+int recursive;     /* Recursively process all the sub-directories */
 
 static char *cur_folder_path; /* Full pathname of the current folder */
 static char *folder_name;     /* Name of the (topmost) folder to be
 				 deleted */
 
-static int
-opt_handler (int key, char *arg, void *unused, struct argp_state *state)
+static void
+set_folder (struct mu_parseopt *po, struct mu_option *opt, char const *arg)
 {
-  switch (key)
-    {
-    case ARG_FOLDER:
-      explicit_folder = 1;
-      folder_name = arg;
-      break;
-
-    case ARG_INTERACTIVE:
-      interactive = is_true (arg);
-      break;
-
-    case ARG_NOINTERACTIVE:
-      interactive = 0;
-      break;
-	
-    case ARG_RECURSIVE:
-      recurse = is_true (arg);
-      break;
-      
-    case ARG_NORECURSIVE:
-      recurse = 0;
-      break;
-
-    case ARG_LICENSE:
-      mh_license (argp_program_version);
-      break;
-
-    default:
-      return 1;
-    }
-  return 0;
-}
+  explicit_folder = 1;
+  folder_name = mu_strdup (arg);
+} 
 
+static struct mu_option options[] = {
+  { "folder",  0, N_("FOLDER"), MU_OPTION_DEFAULT,
+    N_("specify the folder to delete"),
+    mu_c_string, NULL, set_folder },
+  { "interactive", 0, NULL, MU_OPTION_DEFAULT,
+    N_("interactive mode: ask for confirmation before removing each folder"),
+    mu_c_bool, &interactive },
+  { "recursive", 0, NULL, MU_OPTION_DEFAULT,
+    N_("recursively delete all subfolders"),
+    mu_c_bool, &recursive },
+  MU_OPTION_END
+};
+
 static char *
-current_folder_path ()
+current_folder_path (void)
 {
-  mu_mailbox_t mbox = mh_open_folder (mh_current_folder (), 0);
+  mu_mailbox_t mbox = mh_open_folder (mh_current_folder (), MU_STREAM_RDWR);
   mu_url_t url;
   char *p;
   mu_mailbox_get_url (mbox, &url);
@@ -115,6 +72,31 @@ current_folder_path ()
 
 static int
 rmf (const char *name)
+{
+  mu_mailbox_t mbox = NULL;
+  int rc;
+  
+  rc = mu_mailbox_create_default (&mbox, name);
+  if (rc)
+    {
+      mu_error (_("cannot create mailbox %s: %s"),
+		name, strerror (rc));
+      return 1;
+    }
+
+  rc = mu_mailbox_remove (mbox);
+  mu_mailbox_destroy (&mbox);
+  if (rc)
+    {
+      mu_error (_("cannot remove %s: %s"), name, mu_strerror (rc));
+      return 1;
+    }
+  return 0;
+}
+
+/* Recursive rmf */
+static int
+recrmf (const char *name)
 {
   DIR *dir;
   struct dirent *entry;
@@ -140,64 +122,33 @@ rmf (const char *name)
 	  || strcmp (entry->d_name, "..") == 0)
 	continue;
       
-      asprintf (&p, "%s/%s", name, entry->d_name);
+      p = mh_safe_make_file_name (name, entry->d_name);
       if (stat (p, &st) < 0)
 	{
 	  mu_diag_funcall (MU_DIAG_ERROR, "stat", p, errno);
 	}
       else if (S_ISDIR (st.st_mode))
-	{
-	  if (recurse)
-	    failures += rmf (p);
-	  else
-	    {
-	      printf ("%s: file `%s' not deleted, continuing...\n",
-		      mu_program_name, p);
-	      failures++;
-	    }
-	}
-      else
-	{
-	  if (unlink (p))
-	    {
-	      mu_diag_funcall (MU_DIAG_ERROR, "unlink", p, errno);
-	      failures++;
-	    }
-	}
+	failures += recrmf (p);
       free (p);
     }
   closedir (dir);
 
   if (failures == 0)
-    failures += rmdir (name);
+    failures += rmf (name);
   else
     printf ("%s: folder `%s' not removed\n",
 	    mu_program_name, name);
 
-  if (failures == 0)
-    {
-      if (cur_folder_path && strcmp (name, cur_folder_path) == 0)
-	{
-	  mh_set_current_folder ("inbox");
-	  mh_global_sequences_drop ();
-	  mh_global_save_state ();
-	  printf ("[+inbox now current]\n");
-	}
-    }
   return failures;
 }
 
 int
 main (int argc, char **argv)
 {
+  int status;
   char *name;
 
-  /* Native Language Support */
-  MU_APP_INIT_NLS ();
-
-  mh_argp_init (program_version);
-  mh_argp_parse (&argc, &argv, 0, options, mh_option, args_doc, doc,
-		 opt_handler, NULL, NULL);
+  mh_getopt (&argc, &argv, options, 0, NULL, prog_doc, NULL);
 
   cur_folder_path = current_folder_path ();
 
@@ -207,7 +158,24 @@ main (int argc, char **argv)
       name = cur_folder_path;
     }
   else
-    name = mh_expand_name (NULL, folder_name, 0);
-  rmf (name);
-  return 0;
+    name = mh_expand_name (NULL, folder_name, NAME_FOLDER);
+  if (recursive)
+    status = recrmf (name);
+  else
+    {
+      if (interactive && !mh_getyn (_("Remove folder %s"), name))
+	exit (0);
+      status = rmf (name);
+    }
+  if (status == 0)
+    {
+      if (cur_folder_path && strcmp (name, cur_folder_path) == 0)
+	{
+	  mh_set_current_folder ("inbox");
+	  mh_global_save_state ();
+	  printf ("[+inbox now current]\n");
+	}
+      return 0;
+    }      
+  return 1;
 }
