@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2010-2019 Free Software Foundation, Inc.
+   Copyright (C) 2010-2023 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -211,11 +211,14 @@ com_connect (int argc, char **argv)
 	  if (tls)
 	    {
 	      mu_stream_t tlsstream;
-	      
-	      status = mu_tls_client_stream_create (&tlsstream, tcp, tcp, 0);
+
+	      status = mu_tlsfd_stream_convert (&tlsstream, tcp, NULL,
+						MU_TLS_CLIENT);
 	      mu_stream_unref (tcp);
 	      if (status)
 		{
+		  if (status == MU_ERR_TRANSPORT_SET)
+		    mu_stream_destroy (&tlsstream);
 		  mu_error ("cannot create TLS stream: %s",
 			    mu_strerror (status));
 		  return 0;
@@ -224,6 +227,7 @@ com_connect (int argc, char **argv)
 	    }
 #endif
 	  mu_smtp_set_carrier (smtp, tcp);
+	  mu_stream_unref (tcp);
 	  status = smtp_error_handler (mu_smtp_open (smtp));
 	}
       else
@@ -540,7 +544,7 @@ com_send (int argc, char **argv)
     {
       if (msgfile)
 	{
-	  switch (mu_getans ("rReEdD",
+	  switch (mu_getans ("rReEuUdD",
 			     _("Previous message exists. "
 			       "What now: [r]euse, [e]dit, "
 			       "[u]se as a template or\n"
@@ -910,6 +914,8 @@ struct mutool_command smtp_comtab[] = {
 int
 main (int argc, char **argv)
 {
+  mu_set_program_name (argv[0]);
+
   mu_registrar_record (mu_smtp_record);
   mu_registrar_record (mu_smtps_record);
 
