@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2020 Free Software Foundation, Inc.
+   Copyright (C) 1999-2023 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
 
 /* Default signal handler to call the pop3d_abquit() function */
 
-RETSIGTYPE
+void
 pop3d_master_signal (int signo)
 {
   int code;
@@ -41,7 +41,7 @@ pop3d_master_signal (int signo)
   exit (code); 
 }
 
-RETSIGTYPE
+void
 pop3d_child_signal (int signo)
 {
   int code;
