@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2009-2012, 2014-2017 Free Software Foundation, Inc.
+   Copyright (C) 2009-2023 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -25,49 +25,18 @@ _repr (PyObject *self)
 {
   char buf[80];
   sprintf (buf, "<" PY_MODULE "." PY_CSNAME " instance at %p>", self);
-  return PyString_FromString (buf);
+  return PyUnicode_FromString (buf);
 }
 
 static PyTypeObject PyAddressType = {
-  PyObject_HEAD_INIT(NULL)
-  0,                         /* ob_size */
-  PY_MODULE "." PY_CSNAME,   /* tp_name */
-  sizeof (PyAddress),        /* tp_basicsize */
-  0,                         /* tp_itemsize */
-  (destructor)_py_dealloc,   /* tp_dealloc */
-  0,                         /* tp_print */
-  0,                         /* tp_getattr; __getattr__ */
-  0,                         /* tp_setattr; __setattr__ */
-  0,                         /* tp_compare; __cmp__ */
-  _repr,                     /* tp_repr; __repr__ */
-  0,                         /* tp_as_number */
-  0,                         /* tp_as_sequence */
-  0,                         /* tp_as_mapping */
-  0,                         /* tp_hash; __hash__ */
-  0,                         /* tp_call; __call__ */
-  _repr,                     /* tp_str; __str__ */
-  0,                         /* tp_getattro */
-  0,                         /* tp_setattro */
-  0,                         /* tp_as_buffer */
-  Py_TPFLAGS_DEFAULT,        /* tp_flags */
-  "",                        /* tp_doc */
-  0,                         /* tp_traverse */
-  0,                         /* tp_clear */
-  0,                         /* tp_richcompare */
-  0,                         /* tp_weaklistoffset */
-  0,                         /* tp_iter */
-  0,                         /* tp_iternext */
-  0,                         /* tp_methods */
-  0,                         /* tp_members */
-  0,                         /* tp_getset */
-  0,                         /* tp_base */
-  0,                         /* tp_dict */
-  0,                         /* tp_descr_get */
-  0,                         /* tp_descr_set */
-  0,                         /* tp_dictoffset */
-  0,                         /* tp_init */
-  0,                         /* tp_alloc */
-  0,                         /* tp_new */
+  .ob_base = { PyObject_HEAD_INIT(NULL) },
+  .tp_name = PY_MODULE "." PY_CSNAME,
+  .tp_basicsize = sizeof (PyAddress),        
+  .tp_dealloc = (destructor)_py_dealloc,
+  .tp_repr = _repr,
+  .tp_str = _repr,
+  .tp_flags = Py_TPFLAGS_DEFAULT,
+  .tp_doc = "",
 };
 
 PyAddress *
@@ -93,7 +62,7 @@ api_address_create (PyObject *self, PyObject *args)
     return NULL;
 
   status = mu_address_create (&py_addr->addr, str);
-  return _ro (PyInt_FromLong (status));
+  return _ro (PyLong_FromLong (status));
 }
 
 static PyObject *
@@ -128,8 +97,8 @@ api_address_createv (PyObject *self, PyObject *args)
 
       for (i = 0; i < len; i++) {
 	py_item = PySequence_GetItem (py_seq, i);
-	if (py_item && PyString_Check (py_item))
-	  if ((sv[i] = strdup (PyString_AsString (py_item))) == NULL)
+	if (py_item && PyUnicode_Check (py_item))
+	  if ((sv[i] = strdup (PyUnicode_AsUTF8 (py_item))) == NULL)
 	    {
 	      PyErr_NoMemory ();
 	      return NULL;
@@ -142,7 +111,7 @@ api_address_createv (PyObject *self, PyObject *args)
       }
     }
   status = mu_address_createv (&py_addr->addr, (const char**)sv, len);
-  return _ro (PyInt_FromLong (status));
+  return _ro (PyLong_FromLong (status));
 }
 
 static PyObject *
@@ -183,7 +152,7 @@ api_address_get_count (PyObject *self, PyObject *args)
     return NULL;
 
   mu_address_get_count (py_addr->addr, &count);
-  return _ro (PyInt_FromSize_t (count));
+  return _ro (PyLong_FromSize_t (count));
 }
 
 static PyObject *
@@ -200,7 +169,7 @@ api_address_get_email (PyObject *self, PyObject *args)
   ASSERT_INDEX_RANGE (n, "address");
   
   status = mu_address_sget_email (py_addr->addr, n, &buf);
-  return status_object (status, PyString_FromString (buf ? buf : ""));
+  return status_object (status, PyUnicode_FromString (mu_prstr (buf)));
 }
 
 static PyObject *
@@ -217,7 +186,7 @@ api_address_get_local_part (PyObject *self, PyObject *args)
   ASSERT_INDEX_RANGE (n, "address part");
 
   status = mu_address_sget_local_part (py_addr->addr, n, &buf);
-  return status_object (status, PyString_FromString (buf ? buf : ""));
+  return status_object (status, PyUnicode_FromString (mu_prstr (buf)));
 }
 
 static PyObject *
@@ -232,7 +201,7 @@ api_address_get_domain (PyObject *self, PyObject *args)
     return NULL;
   ASSERT_INDEX_RANGE (n, "address part");
   status = mu_address_sget_domain (py_addr->addr, n, &buf);
-  return status_object (status, PyString_FromString (buf ? buf : ""));
+  return status_object (status, PyUnicode_FromString (mu_prstr (buf)));
 }
 
 static PyObject *
@@ -247,7 +216,7 @@ api_address_get_personal (PyObject *self, PyObject *args)
     return NULL;
   ASSERT_INDEX_RANGE (n,  "address part");
   status = mu_address_sget_personal (py_addr->addr, n, &buf);
-  return status_object (status, PyString_FromString (buf ? buf : ""));
+  return status_object (status, PyUnicode_FromString (mu_prstr (buf)));
 }
 
 static PyObject *
@@ -262,7 +231,7 @@ api_address_get_comments (PyObject *self, PyObject *args)
     return NULL;
   ASSERT_INDEX_RANGE (n, "address part");
   status = mu_address_sget_comments (py_addr->addr, n, &buf);
-  return status_object (status, PyString_FromString (buf ? buf : ""));
+  return status_object (status, PyUnicode_FromString (mu_prstr (buf)));
 }
 
 static PyObject *
@@ -277,7 +246,7 @@ api_address_get_route (PyObject *self, PyObject *args)
     return NULL;
   ASSERT_INDEX_RANGE (n, "address part");
   status = mu_address_sget_route (py_addr->addr, n, &buf);
-  return status_object (status, PyString_FromString (buf ? buf : ""));
+  return status_object (status, PyUnicode_FromString (mu_prstr (buf)));
 }
 
 static PyObject *
@@ -291,7 +260,7 @@ api_address_to_string (PyObject *self, PyObject *args)
     return NULL;
 
   status = mu_address_sget_printable (py_addr->addr, &sptr);
-  return status_object (status, PyString_FromString (sptr));
+  return status_object (status, PyUnicode_FromString (mu_prstr (sptr)));
 }
 
 static PyMethodDef methods[] = {
@@ -335,6 +304,14 @@ static PyMethodDef methods[] = {
   { NULL, NULL, 0, NULL }
 };
 
+static struct PyModuleDef moduledef = {
+  PyModuleDef_HEAD_INIT,
+  PY_MODULE,
+  NULL,
+  -1,
+  methods
+};
+
 int
 mu_py_init_address (void)
 {
@@ -346,7 +323,7 @@ void
 _mu_py_attach_address (void)
 {
   PyObject *m;
-  if ((m = _mu_py_attach_module (PY_MODULE, methods)))
+  if ((m = _mu_py_attach_module (&moduledef)))
     {
       Py_INCREF (&PyAddressType);
       PyModule_AddObject (m, PY_CSNAME, (PyObject *)&PyAddressType);
