@@ -1,5 +1,5 @@
 #  GNU Mailutils -- a suite of utilities for electronic mail
-#  Copyright (C) 2009-2012, 2014-2015 Free Software Foundation, Inc.
+#  Copyright (C) 2009-2023 Free Software Foundation, Inc.
 #
 #  This library is free software; you can redistribute it and/or
 #  modify it under the terms of the GNU Lesser General Public
@@ -15,14 +15,13 @@
 #  Public License along with this library.  If not, see 
 #  <http://www.gnu.org/licenses/>. 
 
-import types
 from mailutils.c_api import address
 from mailutils.error import AddressError
 
 class Address:
     def __init__ (self, addr):
         self.addr = address.AddressType ()
-        if isinstance (addr, types.ListType):
+        if isinstance(addr, list):
             status = address.createv (self.addr, addr)
         else:
             status = address.create (self.addr, addr)
@@ -47,7 +46,7 @@ class Address:
         self.__len = self.get_count ()
         return self
 
-    def next (self):
+    def __next__ (self):
         if self.__count >= self.__len:
             self.__count = 0
             raise StopIteration
