@@ -117,7 +117,7 @@
     
   LICENSE
     This program is part of GNU Mailutils testsuite.
-    Copyright (C) 2020 Free Software Foundation, Inc.
+    Copyright (C) 2020-2023 Free Software Foundation, Inc.
 
     Mockmta is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -575,7 +575,7 @@ static void disable_starttls (void);
 # include <gnutls/gnutls.h>
 
 /* TLS support */
-char *tls_cert;			/* TLS sertificate */
+char *tls_cert;			/* TLS certificate */
 char *tls_key;			/* TLS key */
 char *tls_cafile;
 
@@ -1561,7 +1561,7 @@ main (int argc, char **argv)
       else
 	{
 	  /* child */
-	  /* Close unneded descriptors */
+	  /* Close unneeded descriptors */
 	  int i;
 	  for (i = 0; i < sysconf (_SC_OPEN_MAX); i++)
 	    {
